<?php

// If this file is called directly, exit.
if (!defined('WPINC')) {
    die;
}

if (!class_exists('APNASettings')) {
    class APNASettings
    {

        public $base_admin;

        public function __construct($base_admin)
        {
            $this->base_admin = $base_admin;

            $defaultOption = array();
            if (!get_option("apna_automations")) {
                update_option('apna_automations', " ");
            }
            if (!get_option("apna_settings")) {
                update_option('apna_settings', " ");
            }
        }


        public function listAllAutomations()
        {
            $dataRules = get_option("apna_automations");
            return stripslashes($dataRules);
        }

        public function saveAllAutomations($rules)
        {
            update_option('apna_automations', $rules);
            return True;
        }

        public function listAllSettings()
        {
            $dataRules = get_option("apna_settings");
            return stripslashes($dataRules);
        }
        public function saveAllSettings($rules)
        {
            update_option('apna_settings', $rules);
            return True;
        }




        public function detectPostPublished( $new_status, $old_status, $post ) {
            if ( 'publish' === $new_status && 'publish' !== $old_status ) {
                wp_schedule_single_event(time() + 5, 'transition_post_status_scheduled_event', array($post));
            }
        }

        public function detectPostPublishedScheduled( $post ) {
            $all_automations = !empty($this->listAllAutomations()) ? json_decode($this->listAllAutomations(), false) : array();
            foreach ($all_automations as $single_automation){
                if($single_automation->automation_type == "post_publish"){
                    if ( $post->post_type == $single_automation->post_type ) {
                        $post_title = get_the_title($post->ID);
                        $post_id = $post->ID;
                        $post_url = get_permalink($post_id);
                        $thumbnail_url = get_the_post_thumbnail_url($post);
                        $author_id = $post->post_author;
                        $author_name = get_the_author_meta('display_name', $author_id);


                        $replacements = array(
                            '%POST_TITLE%' => $post_title,
                            '%POST_ID%' => $post_id,
                            '%POST_URL%' => $post_url,
                            '%THUMBNAIL_URL%' => $thumbnail_url,
                            '%AUTHOR_NAME%' => $author_name,
                        );

                        $this->sendNotification(
                            strtr($single_automation->notification_title, $replacements),
                            strtr($single_automation->notification_body, $replacements),
                            strtr($single_automation->user_identity, $replacements),
                            strtr($single_automation->open_link_url, $replacements),
                            strtr($single_automation->notification_image, $replacements)
                        );
                    }
                }
            }
        }




        public function detectWooOrderStatusChanged( $order_id, $old_status, $new_status ) {

            $all_automations = !empty($this->listAllAutomations()) ? json_decode($this->listAllAutomations(), false) : array();
            foreach ($all_automations as $single_automation) {
                if ($single_automation->automation_type == "order_status_changed") {

                    if ("wc-".$new_status === $single_automation->order_status || "" === $single_automation->order_status) {
                        $order = wc_get_order($order_id);
                        if (!$order) {
                            return;
                        }
                        $customer_name = $order->get_billing_first_name() . ' ' . $order->get_billing_last_name();
                        $customer_email = $order->get_billing_email();
                        $order_number = $order->get_order_number();
                        $order_total = $order->get_total();
                        $billing_address = $order->get_billing_address_1();

                        $replacements = array(
                            '%ORDER_STATUS%' => ucfirst($new_status),
                            '%CUSTOMER_NAME%' => $customer_name,
                            '%CUSTOMER_EMAIL%' => $customer_email,
                            '%ORDER_NUMBER%' => $order_number,
                            '%ORDER_TOTAL%' => $order_total,
                            '%BILLING_ADDRESS%' => $billing_address,
                        );

                        $this->sendNotification(
                            strtr($single_automation->notification_title, $replacements),
                            strtr($single_automation->notification_body, $replacements),
                            strtr($single_automation->user_identity, $replacements),
                            strtr($single_automation->open_link_url, $replacements),
                            strtr($single_automation->notification_image, $replacements)
                        );
                    }
                }
            }
        }



        public function sendNotification($notification_title = "",
                                         $notification_body = "",
                                         $user_identity = "",
                                         $open_link_url = "",
                                         $notification_image = ""){

            $apna_settings = $this->listAllSettings();
            $apna_settings = json_decode($apna_settings, true);

            if(isset($apna_settings["app_key"]) && isset($apna_settings["api_key"]) && isset($apna_settings["secondary_app_key"]) && isset($apna_settings["secondary_api_key"])){
                if((strlen($apna_settings["app_key"]) > 0 && strlen($apna_settings["api_key"]) > 0) || (strlen($apna_settings["secondary_app_key"]) > 0 && strlen($apna_settings["secondary_api_key"]) > 0)){
                    $url = 'https://appilix.com/api/push-notification';

                    // Data to send in the POST request
                    $data = array(
                        'app_key' => $apna_settings["app_key"],
                        'api_key' => $apna_settings["api_key"],
                        'secondary_app_key' => $apna_settings["secondary_app_key"],
                        'secondary_api_key' => $apna_settings["secondary_api_key"],
                        'notification_title' => $notification_title,
                        'notification_body' => $notification_body,
                        'user_identity' => $user_identity,
                        'open_link_url' => $open_link_url,
                        'notification_image' => $notification_image,
                    );


                    $response = wp_remote_post($url, array(
                        'body' => $data,
                    ));

                }
            }




        }



    }





}
